'''

The MIT License (MIT)

Copyright (c) 2016 WavyCloud

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

'''

def add_attachments_to_set(attachmentSetId=None, attachments=None):
    """
    Adds one or more attachments to an attachment set.
    An attachment set is a temporary container for attachments that you add to a case or case communication. The set is available for 1 hour after it\'s created. The expiryTime returned in the response is when the set expires.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.add_attachments_to_set(
        attachmentSetId='string',
        attachments=[
            {
                'fileName': 'string',
                'data': b'bytes'
            },
        ]
    )
    
    
    :type attachmentSetId: string
    :param attachmentSetId: The ID of the attachment set. If an attachmentSetId is not specified, a new attachment set is created, and the ID of the set is returned in the response. If an attachmentSetId is specified, the attachments are added to the specified set, if it exists.

    :type attachments: list
    :param attachments: [REQUIRED]\nOne or more attachments to add to the set. You can add up to three attachments per set. The size limit is 5 MB per attachment.\nIn the Attachment object, use the data parameter to specify the contents of the attachment file. In the previous request syntax, the value for data appear as blob , which is represented as a base64-encoded string. The value for fileName is the name of the attachment, such as troubleshoot-screenshot.png .\n\n(dict) --An attachment to a case communication. The attachment consists of the file name and the content of the file.\n\nfileName (string) --The name of the attachment file.\n\ndata (bytes) --The content of the attachment file.\n\n\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'attachmentSetId': 'string',
    'expiryTime': 'string'
}


Response Structure

(dict) --
The ID and expiry time of the attachment set returned by the  AddAttachmentsToSet operation.

attachmentSetId (string) --
The ID of the attachment set. If an attachmentSetId was not specified, a new attachment set is created, and the ID of the set is returned in the response. If an attachmentSetId was specified, the attachments are added to the specified set, if it exists.

expiryTime (string) --
The time and date when the attachment set expires.







Exceptions

Support.Client.exceptions.InternalServerError
Support.Client.exceptions.AttachmentSetIdNotFound
Support.Client.exceptions.AttachmentSetExpired
Support.Client.exceptions.AttachmentSetSizeLimitExceeded
Support.Client.exceptions.AttachmentLimitExceeded


    :return: {
        'attachmentSetId': 'string',
        'expiryTime': 'string'
    }
    
    
    :returns: 
    Support.Client.exceptions.InternalServerError
    Support.Client.exceptions.AttachmentSetIdNotFound
    Support.Client.exceptions.AttachmentSetExpired
    Support.Client.exceptions.AttachmentSetSizeLimitExceeded
    Support.Client.exceptions.AttachmentLimitExceeded
    
    """
    pass

def add_communication_to_case(caseId=None, communicationBody=None, ccEmailAddresses=None, attachmentSetId=None):
    """
    Adds additional customer communication to an AWS Support case. You use the caseId value to identify the case to add communication to. You can list a set of email addresses to copy on the communication using the ccEmailAddresses value. The communicationBody value contains the text of the communication.
    The response indicates the success or failure of the request.
    This operation implements a subset of the features of the AWS Support Center.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.add_communication_to_case(
        caseId='string',
        communicationBody='string',
        ccEmailAddresses=[
            'string',
        ],
        attachmentSetId='string'
    )
    
    
    :type caseId: string
    :param caseId: The AWS Support case ID requested or returned in the call. The case ID is an alphanumeric string formatted as shown in this example: case-12345678910-2013-c4c1d2bf33c5cf47

    :type communicationBody: string
    :param communicationBody: [REQUIRED]\nThe body of an email communication to add to the support case.\n

    :type ccEmailAddresses: list
    :param ccEmailAddresses: The email addresses in the CC line of an email to be added to the support case.\n\n(string) --\n\n

    :type attachmentSetId: string
    :param attachmentSetId: The ID of a set of one or more attachments for the communication to add to the case. Create the set by calling AddAttachmentsToSet

    :rtype: dict

ReturnsResponse Syntax
{
    'result': True|False
}


Response Structure

(dict) --
The result of the  AddCommunicationToCase operation.

result (boolean) --
True if  AddCommunicationToCase succeeds. Otherwise, returns an error.







Exceptions

Support.Client.exceptions.InternalServerError
Support.Client.exceptions.CaseIdNotFound
Support.Client.exceptions.AttachmentSetIdNotFound
Support.Client.exceptions.AttachmentSetExpired


    :return: {
        'result': True|False
    }
    
    
    :returns: 
    Support.Client.exceptions.InternalServerError
    Support.Client.exceptions.CaseIdNotFound
    Support.Client.exceptions.AttachmentSetIdNotFound
    Support.Client.exceptions.AttachmentSetExpired
    
    """
    pass

def can_paginate(operation_name=None):
    """
    Check if an operation can be paginated.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name\nas the method name on the client. For example, if the\nmethod name is create_foo, and you\'d normally invoke the\noperation as client.create_foo(**kwargs), if the\ncreate_foo operation can be paginated, you can use the\ncall client.get_paginator('create_foo').

    """
    pass

def create_case(subject=None, serviceCode=None, severityCode=None, categoryCode=None, communicationBody=None, ccEmailAddresses=None, language=None, issueType=None, attachmentSetId=None):
    """
    Creates a case in the AWS Support Center. This operation is similar to how you create a case in the AWS Support Center Create Case page.
    The AWS Support API doesn\'t support requesting service limit increases. You can submit a service limit increase in the following ways:
    A successful  CreateCase request returns an AWS Support case number. You can use the  DescribeCases operation and specify the case number to get existing AWS Support cases. After you create a case, you can use the  AddCommunicationToCase operation to add additional communication or attachments to an existing case.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.create_case(
        subject='string',
        serviceCode='string',
        severityCode='string',
        categoryCode='string',
        communicationBody='string',
        ccEmailAddresses=[
            'string',
        ],
        language='string',
        issueType='string',
        attachmentSetId='string'
    )
    
    
    :type subject: string
    :param subject: [REQUIRED]\nThe title of the AWS Support case. The title appears in the Subject field on the AWS Support Center Create Case page.\n

    :type serviceCode: string
    :param serviceCode: The code for the AWS service. You can use the DescribeServices operation to get the possible serviceCode values.

    :type severityCode: string
    :param severityCode: A value that indicates the urgency of the case. This value determines the response time according to your service level agreement with AWS Support. You can use the DescribeSeverityLevels operation to get the possible values for severityCode .\nFor more information, see SeverityLevel and Choosing a Severity in the AWS Support User Guide .\n\nNote\nThe availability of severity levels depends on the support plan for the AWS account.\n\n

    :type categoryCode: string
    :param categoryCode: The category of problem for the AWS Support case. You also use the DescribeServices operation to get the category code for a service. Each AWS service defines its own set of category codes.

    :type communicationBody: string
    :param communicationBody: [REQUIRED]\nThe communication body text that describes the issue. This text appears in the Description field on the AWS Support Center Create Case page.\n

    :type ccEmailAddresses: list
    :param ccEmailAddresses: A list of email addresses that AWS Support copies on case correspondence. AWS Support identifies the account that creates the case when you specify your AWS credentials in an HTTP POST method or use the AWS SDKs .\n\n(string) --\n\n

    :type language: string
    :param language: The language in which AWS Support handles the case. You must specify the ISO 639-1 code for the language parameter if you want support in that language. Currently, English ('en') and Japanese ('ja') are supported.

    :type issueType: string
    :param issueType: The type of issue for the case. You can specify customer-service or technical . If you don\'t specify a value, the default is technical .

    :type attachmentSetId: string
    :param attachmentSetId: The ID of a set of one or more attachments for the case. Create the set by using the AddAttachmentsToSet operation.

    :rtype: dict

ReturnsResponse Syntax
{
    'caseId': 'string'
}


Response Structure

(dict) --
The AWS Support case ID returned by a successful completion of the  CreateCase operation.

caseId (string) --
The AWS Support case ID requested or returned in the call. The case ID is an alphanumeric string in the following format: case-12345678910-2013-c4c1d2bf33c5cf47







Exceptions

Support.Client.exceptions.InternalServerError
Support.Client.exceptions.CaseCreationLimitExceeded
Support.Client.exceptions.AttachmentSetIdNotFound
Support.Client.exceptions.AttachmentSetExpired


    :return: {
        'caseId': 'string'
    }
    
    
    :returns: 
    The caseId is separate from the displayId that appears in the Support Center . You can use the  DescribeCases operation to get the displayId .
    
    """
    pass

def describe_attachment(attachmentId=None):
    """
    Returns the attachment that has the specified ID. Attachments can include screenshots, error logs, or other files that describe your issue. Attachment IDs are generated by the case management system when you add an attachment to a case or case communication. Attachment IDs are returned in the  AttachmentDetails objects that are returned by the  DescribeCommunications operation.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.describe_attachment(
        attachmentId='string'
    )
    
    
    :type attachmentId: string
    :param attachmentId: [REQUIRED]\nThe ID of the attachment to return. Attachment IDs are returned by the DescribeCommunications operation.\n

    :rtype: dict
ReturnsResponse Syntax{
    'attachment': {
        'fileName': 'string',
        'data': b'bytes'
    }
}


Response Structure

(dict) --The content and file name of the attachment returned by the  DescribeAttachment operation.

attachment (dict) --This object includes the attachment content and file name.
In the previous response syntax, the value for the data parameter appears as blob , which is represented as a base64-encoded string. The value for fileName is the name of the attachment, such as troubleshoot-screenshot.png .

fileName (string) --The name of the attachment file.

data (bytes) --The content of the attachment file.








Exceptions

Support.Client.exceptions.InternalServerError
Support.Client.exceptions.DescribeAttachmentLimitExceeded
Support.Client.exceptions.AttachmentIdNotFound


    :return: {
        'attachment': {
            'fileName': 'string',
            'data': b'bytes'
        }
    }
    
    
    """
    pass

def describe_cases(caseIdList=None, displayId=None, afterTime=None, beforeTime=None, includeResolvedCases=None, nextToken=None, maxResults=None, language=None, includeCommunications=None):
    """
    Returns a list of cases that you specify by passing one or more case IDs. In addition, you can filter the cases by date by setting values for the afterTime and beforeTime request parameters. You can set values for the includeResolvedCases and includeCommunications request parameters to control how much information is returned.
    Case data is available for 12 months after creation. If a case was created more than 12 months ago, a request for data might cause an error.
    The response returns the following in JSON format:
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.describe_cases(
        caseIdList=[
            'string',
        ],
        displayId='string',
        afterTime='string',
        beforeTime='string',
        includeResolvedCases=True|False,
        nextToken='string',
        maxResults=123,
        language='string',
        includeCommunications=True|False
    )
    
    
    :type caseIdList: list
    :param caseIdList: A list of ID numbers of the support cases you want returned. The maximum number of cases is 100.\n\n(string) --\n\n

    :type displayId: string
    :param displayId: The ID displayed for a case in the AWS Support Center user interface.

    :type afterTime: string
    :param afterTime: The start date for a filtered date search on support case communications. Case communications are available for 12 months after creation.

    :type beforeTime: string
    :param beforeTime: The end date for a filtered date search on support case communications. Case communications are available for 12 months after creation.

    :type includeResolvedCases: boolean
    :param includeResolvedCases: Specifies whether resolved support cases should be included in the DescribeCases results. The default is false .

    :type nextToken: string
    :param nextToken: A resumption point for pagination.

    :type maxResults: integer
    :param maxResults: The maximum number of results to return before paginating.

    :type language: string
    :param language: The ISO 639-1 code for the language in which AWS provides support. AWS Support currently supports English ('en') and Japanese ('ja'). Language parameters must be passed explicitly for operations that take them.

    :type includeCommunications: boolean
    :param includeCommunications: Specifies whether communications should be included in the DescribeCases results. The default is true .

    :rtype: dict

ReturnsResponse Syntax
{
    'cases': [
        {
            'caseId': 'string',
            'displayId': 'string',
            'subject': 'string',
            'status': 'string',
            'serviceCode': 'string',
            'categoryCode': 'string',
            'severityCode': 'string',
            'submittedBy': 'string',
            'timeCreated': 'string',
            'recentCommunications': {
                'communications': [
                    {
                        'caseId': 'string',
                        'body': 'string',
                        'submittedBy': 'string',
                        'timeCreated': 'string',
                        'attachmentSet': [
                            {
                                'attachmentId': 'string',
                                'fileName': 'string'
                            },
                        ]
                    },
                ],
                'nextToken': 'string'
            },
            'ccEmailAddresses': [
                'string',
            ],
            'language': 'string'
        },
    ],
    'nextToken': 'string'
}


Response Structure

(dict) --
Returns an array of  CaseDetails objects and a nextToken that defines a point for pagination in the result set.

cases (list) --
The details for the cases that match the request.

(dict) --
A JSON-formatted object that contains the metadata for a support case. It is contained the response from a  DescribeCases request. CaseDetails contains the following fields:

caseId. The AWS Support case ID requested or returned in the call. The case ID is an alphanumeric string formatted as shown in this example: case-12345678910-2013-c4c1d2bf33c5cf47 .
categoryCode. The category of problem for the AWS Support case. Corresponds to the CategoryCode values returned by a call to  DescribeServices .
displayId. The identifier for the case on pages in the AWS Support Center.
language. The ISO 639-1 code for the language in which AWS provides support. AWS Support currently supports English ("en") and Japanese ("ja"). Language parameters must be passed explicitly for operations that take them.
recentCommunications. One or more  Communication objects. Fields of these objects are attachments , body , caseId , submittedBy , and timeCreated .
nextToken. A resumption point for pagination.
serviceCode. The identifier for the AWS service that corresponds to the service code defined in the call to  DescribeServices .
severityCode. The severity code assigned to the case. Contains one of the values returned by the call to  DescribeSeverityLevels . The possible values are: low , normal , high , urgent , and critical .
status. The status of the case in the AWS Support Center. Valid values:
opened
pending-customer-action
reopened
resolved
unassigned
work-in-progress


subject. The subject line of the case.
submittedBy. The email address of the account that submitted the case.
timeCreated. The time the case was created, in ISO-8601 format.


caseId (string) --
The AWS Support case ID requested or returned in the call. The case ID is an alphanumeric string formatted as shown in this example: case-12345678910-2013-c4c1d2bf33c5cf47

displayId (string) --
The ID displayed for the case in the AWS Support Center. This is a numeric string.

subject (string) --
The subject line for the case in the AWS Support Center.

status (string) --
The status of the case.
Valid values:

opened
pending-customer-action
reopened
resolved
unassigned
work-in-progress


serviceCode (string) --
The code for the AWS service. You can get a list of codes and the corresponding service names by calling  DescribeServices .

categoryCode (string) --
The category of problem for the AWS Support case.

severityCode (string) --
The code for the severity level returned by the call to  DescribeSeverityLevels .

submittedBy (string) --
The email address of the account that submitted the case.

timeCreated (string) --
The time that the case was case created in the AWS Support Center.

recentCommunications (dict) --
The five most recent communications between you and AWS Support Center, including the IDs of any attachments to the communications. Also includes a nextToken that you can use to retrieve earlier communications.

communications (list) --
The five most recent communications associated with the case.

(dict) --
A communication associated with an AWS Support case. The communication consists of the case ID, the message body, attachment information, the submitter of the communication, and the date and time of the communication.

caseId (string) --
The AWS Support case ID requested or returned in the call. The case ID is an alphanumeric string formatted as shown in this example: case-12345678910-2013-c4c1d2bf33c5cf47

body (string) --
The text of the communication between the customer and AWS Support.

submittedBy (string) --
The identity of the account that submitted, or responded to, the support case. Customer entries include the role or IAM user as well as the email address. For example, "AdminRole (Role) <someone@example.com>. Entries from the AWS Support team display "Amazon Web Services," and do not show an email address.

timeCreated (string) --
The time the communication was created.

attachmentSet (list) --
Information about the attachments to the case communication.

(dict) --
The file name and ID of an attachment to a case communication. You can use the ID to retrieve the attachment with the  DescribeAttachment operation.

attachmentId (string) --
The ID of the attachment.

fileName (string) --
The file name of the attachment.









nextToken (string) --
A resumption point for pagination.



ccEmailAddresses (list) --
The email addresses that receive copies of communication about the case.

(string) --


language (string) --
The ISO 639-1 code for the language in which AWS provides support. AWS Support currently supports English ("en") and Japanese ("ja"). Language parameters must be passed explicitly for operations that take them.





nextToken (string) --
A resumption point for pagination.







Exceptions

Support.Client.exceptions.InternalServerError
Support.Client.exceptions.CaseIdNotFound


    :return: {
        'cases': [
            {
                'caseId': 'string',
                'displayId': 'string',
                'subject': 'string',
                'status': 'string',
                'serviceCode': 'string',
                'categoryCode': 'string',
                'severityCode': 'string',
                'submittedBy': 'string',
                'timeCreated': 'string',
                'recentCommunications': {
                    'communications': [
                        {
                            'caseId': 'string',
                            'body': 'string',
                            'submittedBy': 'string',
                            'timeCreated': 'string',
                            'attachmentSet': [
                                {
                                    'attachmentId': 'string',
                                    'fileName': 'string'
                                },
                            ]
                        },
                    ],
                    'nextToken': 'string'
                },
                'ccEmailAddresses': [
                    'string',
                ],
                'language': 'string'
            },
        ],
        'nextToken': 'string'
    }
    
    
    :returns: 
    caseIdList (list) -- A list of ID numbers of the support cases you want returned. The maximum number of cases is 100.
    
    (string) --
    
    
    displayId (string) -- The ID displayed for a case in the AWS Support Center user interface.
    afterTime (string) -- The start date for a filtered date search on support case communications. Case communications are available for 12 months after creation.
    beforeTime (string) -- The end date for a filtered date search on support case communications. Case communications are available for 12 months after creation.
    includeResolvedCases (boolean) -- Specifies whether resolved support cases should be included in the  DescribeCases results. The default is false .
    nextToken (string) -- A resumption point for pagination.
    maxResults (integer) -- The maximum number of results to return before paginating.
    language (string) -- The ISO 639-1 code for the language in which AWS provides support. AWS Support currently supports English ("en") and Japanese ("ja"). Language parameters must be passed explicitly for operations that take them.
    includeCommunications (boolean) -- Specifies whether communications should be included in the  DescribeCases results. The default is true .
    
    """
    pass

def describe_communications(caseId=None, beforeTime=None, afterTime=None, nextToken=None, maxResults=None):
    """
    Returns communications (and attachments) for one or more support cases. You can use the afterTime and beforeTime parameters to filter by date. You can use the caseId parameter to restrict the results to a particular case.
    Case data is available for 12 months after creation. If a case was created more than 12 months ago, a request for data might cause an error.
    You can use the maxResults and nextToken parameters to control the pagination of the result set. Set maxResults to the number of cases you want displayed on each page, and use nextToken to specify the resumption of pagination.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.describe_communications(
        caseId='string',
        beforeTime='string',
        afterTime='string',
        nextToken='string',
        maxResults=123
    )
    
    
    :type caseId: string
    :param caseId: [REQUIRED]\nThe AWS Support case ID requested or returned in the call. The case ID is an alphanumeric string formatted as shown in this example: case-12345678910-2013-c4c1d2bf33c5cf47\n

    :type beforeTime: string
    :param beforeTime: The end date for a filtered date search on support case communications. Case communications are available for 12 months after creation.

    :type afterTime: string
    :param afterTime: The start date for a filtered date search on support case communications. Case communications are available for 12 months after creation.

    :type nextToken: string
    :param nextToken: A resumption point for pagination.

    :type maxResults: integer
    :param maxResults: The maximum number of results to return before paginating.

    :rtype: dict

ReturnsResponse Syntax
{
    'communications': [
        {
            'caseId': 'string',
            'body': 'string',
            'submittedBy': 'string',
            'timeCreated': 'string',
            'attachmentSet': [
                {
                    'attachmentId': 'string',
                    'fileName': 'string'
                },
            ]
        },
    ],
    'nextToken': 'string'
}


Response Structure

(dict) --
The communications returned by the  DescribeCommunications operation.

communications (list) --
The communications for the case.

(dict) --
A communication associated with an AWS Support case. The communication consists of the case ID, the message body, attachment information, the submitter of the communication, and the date and time of the communication.

caseId (string) --
The AWS Support case ID requested or returned in the call. The case ID is an alphanumeric string formatted as shown in this example: case-12345678910-2013-c4c1d2bf33c5cf47

body (string) --
The text of the communication between the customer and AWS Support.

submittedBy (string) --
The identity of the account that submitted, or responded to, the support case. Customer entries include the role or IAM user as well as the email address. For example, "AdminRole (Role) <someone@example.com>. Entries from the AWS Support team display "Amazon Web Services," and do not show an email address.

timeCreated (string) --
The time the communication was created.

attachmentSet (list) --
Information about the attachments to the case communication.

(dict) --
The file name and ID of an attachment to a case communication. You can use the ID to retrieve the attachment with the  DescribeAttachment operation.

attachmentId (string) --
The ID of the attachment.

fileName (string) --
The file name of the attachment.









nextToken (string) --
A resumption point for pagination.







Exceptions

Support.Client.exceptions.InternalServerError
Support.Client.exceptions.CaseIdNotFound


    :return: {
        'communications': [
            {
                'caseId': 'string',
                'body': 'string',
                'submittedBy': 'string',
                'timeCreated': 'string',
                'attachmentSet': [
                    {
                        'attachmentId': 'string',
                        'fileName': 'string'
                    },
                ]
            },
        ],
        'nextToken': 'string'
    }
    
    
    :returns: 
    Support.Client.exceptions.InternalServerError
    Support.Client.exceptions.CaseIdNotFound
    
    """
    pass

def describe_services(serviceCodeList=None, language=None):
    """
    Returns the current list of AWS services and a list of service categories that applies to each one. You then use service names and categories in your  CreateCase requests. Each AWS service has its own set of categories.
    The service codes and category codes correspond to the values that are displayed in the Service and Category drop-down lists on the AWS Support Center Create Case page. The values in those fields, however, do not necessarily match the service codes and categories returned by the DescribeServices request. Always use the service codes and categories obtained programmatically. This practice ensures that you always have the most recent set of service and category codes.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.describe_services(
        serviceCodeList=[
            'string',
        ],
        language='string'
    )
    
    
    :type serviceCodeList: list
    :param serviceCodeList: A JSON-formatted list of service codes available for AWS services.\n\n(string) --\n\n

    :type language: string
    :param language: The ISO 639-1 code for the language in which AWS provides support. AWS Support currently supports English ('en') and Japanese ('ja'). Language parameters must be passed explicitly for operations that take them.

    :rtype: dict

ReturnsResponse Syntax
{
    'services': [
        {
            'code': 'string',
            'name': 'string',
            'categories': [
                {
                    'code': 'string',
                    'name': 'string'
                },
            ]
        },
    ]
}


Response Structure

(dict) --
The list of AWS services returned by the  DescribeServices operation.

services (list) --
A JSON-formatted list of AWS services.

(dict) --
Information about an AWS service returned by the  DescribeServices operation.

code (string) --
The code for an AWS service returned by the  DescribeServices response. The name element contains the corresponding friendly name.

name (string) --
The friendly name for an AWS service. The code element contains the corresponding code.

categories (list) --
A list of categories that describe the type of support issue a case describes. Categories consist of a category name and a category code. Category names and codes are passed to AWS Support when you call  CreateCase .

(dict) --
A JSON-formatted name/value pair that represents the category name and category code of the problem, selected from the  DescribeServices response for each AWS service.

code (string) --
The category code for the support case.

name (string) --
The category name for the support case.















Exceptions

Support.Client.exceptions.InternalServerError


    :return: {
        'services': [
            {
                'code': 'string',
                'name': 'string',
                'categories': [
                    {
                        'code': 'string',
                        'name': 'string'
                    },
                ]
            },
        ]
    }
    
    
    :returns: 
    Support.Client.exceptions.InternalServerError
    
    """
    pass

def describe_severity_levels(language=None):
    """
    Returns the list of severity levels that you can assign to an AWS Support case. The severity level for a case is also a field in the  CaseDetails data type included in any  CreateCase request.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.describe_severity_levels(
        language='string'
    )
    
    
    :type language: string
    :param language: The ISO 639-1 code for the language in which AWS provides support. AWS Support currently supports English ('en') and Japanese ('ja'). Language parameters must be passed explicitly for operations that take them.

    :rtype: dict
ReturnsResponse Syntax{
    'severityLevels': [
        {
            'code': 'string',
            'name': 'string'
        },
    ]
}


Response Structure

(dict) --The list of severity levels returned by the  DescribeSeverityLevels operation.

severityLevels (list) --The available severity levels for the support case. Available severity levels are defined by your service level agreement with AWS.

(dict) --A code and name pair that represents the severity level of a support case. The available values depend on the support plan for the account. For more information, see Choosing a Severity .

code (string) --The code for case severity level.
Valid values: low | normal | high | urgent | critical

name (string) --The name of the severity level that corresponds to the severity level code.

Note
The values returned by the API differ from the values that are displayed in the AWS Support Center. For example, for the code "low", the API name is "Low", but the name in the Support Center is "General guidance". These are the Support Center code/name mappings:

low : General guidance
normal : System impaired
high : Production system impaired
urgent : Production system down
critical : Business-critical system down


For more information, see Choosing a Severity










Exceptions

Support.Client.exceptions.InternalServerError


    :return: {
        'severityLevels': [
            {
                'code': 'string',
                'name': 'string'
            },
        ]
    }
    
    
    :returns: 
    Support.Client.exceptions.InternalServerError
    
    """
    pass

def describe_trusted_advisor_check_refresh_statuses(checkIds=None):
    """
    Returns the refresh status of the Trusted Advisor checks that have the specified check IDs. Check IDs can be obtained by calling  DescribeTrustedAdvisorChecks .
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.describe_trusted_advisor_check_refresh_statuses(
        checkIds=[
            'string',
        ]
    )
    
    
    :type checkIds: list
    :param checkIds: [REQUIRED]\nThe IDs of the Trusted Advisor checks to get the status of. Note: Specifying the check ID of a check that is automatically refreshed causes an InvalidParameterValue error.\n\n(string) --\n\n

    :rtype: dict
ReturnsResponse Syntax{
    'statuses': [
        {
            'checkId': 'string',
            'status': 'string',
            'millisUntilNextRefreshable': 123
        },
    ]
}


Response Structure

(dict) --The statuses of the Trusted Advisor checks returned by the  DescribeTrustedAdvisorCheckRefreshStatuses operation.

statuses (list) --The refresh status of the specified Trusted Advisor checks.

(dict) --The refresh status of a Trusted Advisor check.

checkId (string) --The unique identifier for the Trusted Advisor check.

status (string) --The status of the Trusted Advisor check for which a refresh has been requested:

none: The check is not refreshed or the non-success status exceeds the timeout
enqueued: The check refresh requests has entered the refresh queue
processing: The check refresh request is picked up by the rule processing engine
success: The check is successfully refreshed
abandoned: The check refresh has failed


millisUntilNextRefreshable (integer) --The amount of time, in milliseconds, until the Trusted Advisor check is eligible for refresh.










Exceptions

Support.Client.exceptions.InternalServerError


    :return: {
        'statuses': [
            {
                'checkId': 'string',
                'status': 'string',
                'millisUntilNextRefreshable': 123
            },
        ]
    }
    
    
    :returns: 
    none: The check is not refreshed or the non-success status exceeds the timeout
    enqueued: The check refresh requests has entered the refresh queue
    processing: The check refresh request is picked up by the rule processing engine
    success: The check is successfully refreshed
    abandoned: The check refresh has failed
    
    """
    pass

def describe_trusted_advisor_check_result(checkId=None, language=None):
    """
    Returns the results of the Trusted Advisor check that has the specified check ID. Check IDs can be obtained by calling  DescribeTrustedAdvisorChecks .
    The response contains a  TrustedAdvisorCheckResult object, which contains these three objects:
    In addition, the response contains these fields:
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.describe_trusted_advisor_check_result(
        checkId='string',
        language='string'
    )
    
    
    :type checkId: string
    :param checkId: [REQUIRED]\nThe unique identifier for the Trusted Advisor check.\n

    :type language: string
    :param language: The ISO 639-1 code for the language in which AWS provides support. AWS Support currently supports English ('en') and Japanese ('ja'). Language parameters must be passed explicitly for operations that take them.

    :rtype: dict

ReturnsResponse Syntax
{
    'result': {
        'checkId': 'string',
        'timestamp': 'string',
        'status': 'string',
        'resourcesSummary': {
            'resourcesProcessed': 123,
            'resourcesFlagged': 123,
            'resourcesIgnored': 123,
            'resourcesSuppressed': 123
        },
        'categorySpecificSummary': {
            'costOptimizing': {
                'estimatedMonthlySavings': 123.0,
                'estimatedPercentMonthlySavings': 123.0
            }
        },
        'flaggedResources': [
            {
                'status': 'string',
                'region': 'string',
                'resourceId': 'string',
                'isSuppressed': True|False,
                'metadata': [
                    'string',
                ]
            },
        ]
    }
}


Response Structure

(dict) --
The result of the Trusted Advisor check returned by the  DescribeTrustedAdvisorCheckResult operation.

result (dict) --
The detailed results of the Trusted Advisor check.

checkId (string) --
The unique identifier for the Trusted Advisor check.

timestamp (string) --
The time of the last refresh of the check.

status (string) --
The alert status of the check: "ok" (green), "warning" (yellow), "error" (red), or "not_available".

resourcesSummary (dict) --
Details about AWS resources that were analyzed in a call to Trusted Advisor  DescribeTrustedAdvisorCheckSummaries .

resourcesProcessed (integer) --
The number of AWS resources that were analyzed by the Trusted Advisor check.

resourcesFlagged (integer) --
The number of AWS resources that were flagged (listed) by the Trusted Advisor check.

resourcesIgnored (integer) --
The number of AWS resources ignored by Trusted Advisor because information was unavailable.

resourcesSuppressed (integer) --
The number of AWS resources ignored by Trusted Advisor because they were marked as suppressed by the user.



categorySpecificSummary (dict) --
Summary information that relates to the category of the check. Cost Optimizing is the only category that is currently supported.

costOptimizing (dict) --
The summary information about cost savings for a Trusted Advisor check that is in the Cost Optimizing category.

estimatedMonthlySavings (float) --
The estimated monthly savings that might be realized if the recommended operations are taken.

estimatedPercentMonthlySavings (float) --
The estimated percentage of savings that might be realized if the recommended operations are taken.





flaggedResources (list) --
The details about each resource listed in the check result.

(dict) --
Contains information about a resource identified by a Trusted Advisor check.

status (string) --
The status code for the resource identified in the Trusted Advisor check.

region (string) --
The AWS region in which the identified resource is located.

resourceId (string) --
The unique identifier for the identified resource.

isSuppressed (boolean) --
Specifies whether the AWS resource was ignored by Trusted Advisor because it was marked as suppressed by the user.

metadata (list) --
Additional information about the identified resource. The exact metadata and its order can be obtained by inspecting the  TrustedAdvisorCheckDescription object returned by the call to  DescribeTrustedAdvisorChecks . Metadata contains all the data that is shown in the Excel download, even in those cases where the UI shows just summary data.

(string) --














Exceptions

Support.Client.exceptions.InternalServerError


    :return: {
        'result': {
            'checkId': 'string',
            'timestamp': 'string',
            'status': 'string',
            'resourcesSummary': {
                'resourcesProcessed': 123,
                'resourcesFlagged': 123,
                'resourcesIgnored': 123,
                'resourcesSuppressed': 123
            },
            'categorySpecificSummary': {
                'costOptimizing': {
                    'estimatedMonthlySavings': 123.0,
                    'estimatedPercentMonthlySavings': 123.0
                }
            },
            'flaggedResources': [
                {
                    'status': 'string',
                    'region': 'string',
                    'resourceId': 'string',
                    'isSuppressed': True|False,
                    'metadata': [
                        'string',
                    ]
                },
            ]
        }
    }
    
    
    :returns: 
    status. The alert status of the check: "ok" (green), "warning" (yellow), "error" (red), or "not_available".
    timestamp. The time of the last refresh of the check.
    checkId. The unique identifier for the check.
    
    """
    pass

def describe_trusted_advisor_check_summaries(checkIds=None):
    """
    Returns the summaries of the results of the Trusted Advisor checks that have the specified check IDs. Check IDs can be obtained by calling  DescribeTrustedAdvisorChecks .
    The response contains an array of  TrustedAdvisorCheckSummary objects.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.describe_trusted_advisor_check_summaries(
        checkIds=[
            'string',
        ]
    )
    
    
    :type checkIds: list
    :param checkIds: [REQUIRED]\nThe IDs of the Trusted Advisor checks.\n\n(string) --\n\n

    :rtype: dict
ReturnsResponse Syntax{
    'summaries': [
        {
            'checkId': 'string',
            'timestamp': 'string',
            'status': 'string',
            'hasFlaggedResources': True|False,
            'resourcesSummary': {
                'resourcesProcessed': 123,
                'resourcesFlagged': 123,
                'resourcesIgnored': 123,
                'resourcesSuppressed': 123
            },
            'categorySpecificSummary': {
                'costOptimizing': {
                    'estimatedMonthlySavings': 123.0,
                    'estimatedPercentMonthlySavings': 123.0
                }
            }
        },
    ]
}


Response Structure

(dict) --The summaries of the Trusted Advisor checks returned by the  DescribeTrustedAdvisorCheckSummaries operation.

summaries (list) --The summary information for the requested Trusted Advisor checks.

(dict) --A summary of a Trusted Advisor check result, including the alert status, last refresh, and number of resources examined.

checkId (string) --The unique identifier for the Trusted Advisor check.

timestamp (string) --The time of the last refresh of the check.

status (string) --The alert status of the check: "ok" (green), "warning" (yellow), "error" (red), or "not_available".

hasFlaggedResources (boolean) --Specifies whether the Trusted Advisor check has flagged resources.

resourcesSummary (dict) --Details about AWS resources that were analyzed in a call to Trusted Advisor  DescribeTrustedAdvisorCheckSummaries .

resourcesProcessed (integer) --The number of AWS resources that were analyzed by the Trusted Advisor check.

resourcesFlagged (integer) --The number of AWS resources that were flagged (listed) by the Trusted Advisor check.

resourcesIgnored (integer) --The number of AWS resources ignored by Trusted Advisor because information was unavailable.

resourcesSuppressed (integer) --The number of AWS resources ignored by Trusted Advisor because they were marked as suppressed by the user.



categorySpecificSummary (dict) --Summary information that relates to the category of the check. Cost Optimizing is the only category that is currently supported.

costOptimizing (dict) --The summary information about cost savings for a Trusted Advisor check that is in the Cost Optimizing category.

estimatedMonthlySavings (float) --The estimated monthly savings that might be realized if the recommended operations are taken.

estimatedPercentMonthlySavings (float) --The estimated percentage of savings that might be realized if the recommended operations are taken.














Exceptions

Support.Client.exceptions.InternalServerError


    :return: {
        'summaries': [
            {
                'checkId': 'string',
                'timestamp': 'string',
                'status': 'string',
                'hasFlaggedResources': True|False,
                'resourcesSummary': {
                    'resourcesProcessed': 123,
                    'resourcesFlagged': 123,
                    'resourcesIgnored': 123,
                    'resourcesSuppressed': 123
                },
                'categorySpecificSummary': {
                    'costOptimizing': {
                        'estimatedMonthlySavings': 123.0,
                        'estimatedPercentMonthlySavings': 123.0
                    }
                }
            },
        ]
    }
    
    
    :returns: 
    Support.Client.exceptions.InternalServerError
    
    """
    pass

def describe_trusted_advisor_checks(language=None):
    """
    Returns information about all available Trusted Advisor checks, including name, ID, category, description, and metadata. You must specify a language code; English ("en") and Japanese ("ja") are currently supported. The response contains a  TrustedAdvisorCheckDescription for each check. The region must be set to us-east-1.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.describe_trusted_advisor_checks(
        language='string'
    )
    
    
    :type language: string
    :param language: [REQUIRED]\nThe ISO 639-1 code for the language in which AWS provides support. AWS Support currently supports English ('en') and Japanese ('ja'). Language parameters must be passed explicitly for operations that take them.\n

    :rtype: dict
ReturnsResponse Syntax{
    'checks': [
        {
            'id': 'string',
            'name': 'string',
            'description': 'string',
            'category': 'string',
            'metadata': [
                'string',
            ]
        },
    ]
}


Response Structure

(dict) --Information about the Trusted Advisor checks returned by the  DescribeTrustedAdvisorChecks operation.

checks (list) --Information about all available Trusted Advisor checks.

(dict) --The description and metadata for a Trusted Advisor check.

id (string) --The unique identifier for the Trusted Advisor check.

name (string) --The display name for the Trusted Advisor check.

description (string) --The description of the Trusted Advisor check, which includes the alert criteria and recommended operations (contains HTML markup).

category (string) --The category of the Trusted Advisor check.

metadata (list) --The column headings for the data returned by the Trusted Advisor check. The order of the headings corresponds to the order of the data in the Metadata element of the  TrustedAdvisorResourceDetail for the check. Metadata contains all the data that is shown in the Excel download, even in those cases where the UI shows just summary data.

(string) --











Exceptions

Support.Client.exceptions.InternalServerError


    :return: {
        'checks': [
            {
                'id': 'string',
                'name': 'string',
                'description': 'string',
                'category': 'string',
                'metadata': [
                    'string',
                ]
            },
        ]
    }
    
    
    :returns: 
    Support.Client.exceptions.InternalServerError
    
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    Generate a presigned url given a client, its method, and arguments
    
    :type ClientMethod: string
    :param ClientMethod: The client method to presign for

    :type Params: dict
    :param Params: The parameters normally passed to\nClientMethod.

    :type ExpiresIn: int
    :param ExpiresIn: The number of seconds the presigned url is valid\nfor. By default it expires in an hour (3600 seconds)

    :type HttpMethod: string
    :param HttpMethod: The http method to use on the generated url. By\ndefault, the http method is whatever is used in the method\'s model.

    """
    pass

def get_paginator(operation_name=None):
    """
    Create a paginator for an operation.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name\nas the method name on the client. For example, if the\nmethod name is create_foo, and you\'d normally invoke the\noperation as client.create_foo(**kwargs), if the\ncreate_foo operation can be paginated, you can use the\ncall client.get_paginator('create_foo').

    :rtype: L{botocore.paginate.Paginator}
ReturnsA paginator object.


    """
    pass

def get_waiter(waiter_name=None):
    """
    Returns an object that can wait for some condition.
    
    :type waiter_name: str
    :param waiter_name: The name of the waiter to get. See the waiters\nsection of the service docs for a list of available waiters.

    :rtype: botocore.waiter.Waiter


    """
    pass

def refresh_trusted_advisor_check(checkId=None):
    """
    Requests a refresh of the Trusted Advisor check that has the specified check ID. Check IDs can be obtained by calling  DescribeTrustedAdvisorChecks .
    The response contains a  TrustedAdvisorCheckRefreshStatus object, which contains these fields:
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.refresh_trusted_advisor_check(
        checkId='string'
    )
    
    
    :type checkId: string
    :param checkId: [REQUIRED]\nThe unique identifier for the Trusted Advisor check to refresh. Note: Specifying the check ID of a check that is automatically refreshed causes an InvalidParameterValue error.\n

    :rtype: dict
ReturnsResponse Syntax{
    'status': {
        'checkId': 'string',
        'status': 'string',
        'millisUntilNextRefreshable': 123
    }
}


Response Structure

(dict) --The current refresh status of a Trusted Advisor check.

status (dict) --The current refresh status for a check, including the amount of time until the check is eligible for refresh.

checkId (string) --The unique identifier for the Trusted Advisor check.

status (string) --The status of the Trusted Advisor check for which a refresh has been requested:

none: The check is not refreshed or the non-success status exceeds the timeout
enqueued: The check refresh requests has entered the refresh queue
processing: The check refresh request is picked up by the rule processing engine
success: The check is successfully refreshed
abandoned: The check refresh has failed


millisUntilNextRefreshable (integer) --The amount of time, in milliseconds, until the Trusted Advisor check is eligible for refresh.








Exceptions

Support.Client.exceptions.InternalServerError


    :return: {
        'status': {
            'checkId': 'string',
            'status': 'string',
            'millisUntilNextRefreshable': 123
        }
    }
    
    
    :returns: 
    none: The check is not refreshed or the non-success status exceeds the timeout
    enqueued: The check refresh requests has entered the refresh queue
    processing: The check refresh request is picked up by the rule processing engine
    success: The check is successfully refreshed
    abandoned: The check refresh has failed
    
    """
    pass

def resolve_case(caseId=None):
    """
    Takes a caseId and returns the initial state of the case along with the state of the case after the call to  ResolveCase completed.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.resolve_case(
        caseId='string'
    )
    
    
    :type caseId: string
    :param caseId: The AWS Support case ID requested or returned in the call. The case ID is an alphanumeric string formatted as shown in this example: case-12345678910-2013-c4c1d2bf33c5cf47

    :rtype: dict
ReturnsResponse Syntax{
    'initialCaseStatus': 'string',
    'finalCaseStatus': 'string'
}


Response Structure

(dict) --The status of the case returned by the  ResolveCase operation.

initialCaseStatus (string) --The status of the case when the  ResolveCase request was sent.

finalCaseStatus (string) --The status of the case after the  ResolveCase request was processed.






Exceptions

Support.Client.exceptions.InternalServerError
Support.Client.exceptions.CaseIdNotFound


    :return: {
        'initialCaseStatus': 'string',
        'finalCaseStatus': 'string'
    }
    
    
    """
    pass




'''

The MIT License (MIT)

Copyright (c) 2016 WavyCloud

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

'''

def activate_pipeline(pipelineId=None, parameterValues=None, startTimestamp=None):
    """
    Validates the specified pipeline and starts processing pipeline tasks. If the pipeline does not pass validation, activation fails.
    If you need to pause the pipeline to investigate an issue with a component, such as a data source or script, call  DeactivatePipeline .
    To activate a finished pipeline, modify the end date for the pipeline and then activate it.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.activate_pipeline(
        pipelineId='string',
        parameterValues=[
            {
                'id': 'string',
                'stringValue': 'string'
            },
        ],
        startTimestamp=datetime(2015, 1, 1)
    )
    
    
    :type pipelineId: string
    :param pipelineId: [REQUIRED]\nThe ID of the pipeline.\n

    :type parameterValues: list
    :param parameterValues: A list of parameter values to pass to the pipeline at activation.\n\n(dict) --A value or list of parameter values.\n\nid (string) -- [REQUIRED]The ID of the parameter value.\n\nstringValue (string) -- [REQUIRED]The field value, expressed as a String.\n\n\n\n\n

    :type startTimestamp: datetime
    :param startTimestamp: The date and time to resume the pipeline. By default, the pipeline resumes from the last completed execution.

    :rtype: dict

ReturnsResponse Syntax
{}


Response Structure

(dict) --
Contains the output of ActivatePipeline.





Exceptions

DataPipeline.Client.exceptions.PipelineNotFoundException
DataPipeline.Client.exceptions.PipelineDeletedException
DataPipeline.Client.exceptions.InternalServiceError
DataPipeline.Client.exceptions.InvalidRequestException


    :return: {}
    
    
    :returns: 
    DataPipeline.Client.exceptions.PipelineNotFoundException
    DataPipeline.Client.exceptions.PipelineDeletedException
    DataPipeline.Client.exceptions.InternalServiceError
    DataPipeline.Client.exceptions.InvalidRequestException
    
    """
    pass

def add_tags(pipelineId=None, tags=None):
    """
    Adds or modifies tags for the specified pipeline.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.add_tags(
        pipelineId='string',
        tags=[
            {
                'key': 'string',
                'value': 'string'
            },
        ]
    )
    
    
    :type pipelineId: string
    :param pipelineId: [REQUIRED]\nThe ID of the pipeline.\n

    :type tags: list
    :param tags: [REQUIRED]\nThe tags to add, as key/value pairs.\n\n(dict) --Tags are key/value pairs defined by a user and associated with a pipeline to control access. AWS Data Pipeline allows you to associate ten tags per pipeline. For more information, see Controlling User Access to Pipelines in the AWS Data Pipeline Developer Guide .\n\nkey (string) -- [REQUIRED]The key name of a tag defined by a user. For more information, see Controlling User Access to Pipelines in the AWS Data Pipeline Developer Guide .\n\nvalue (string) -- [REQUIRED]The optional value portion of a tag defined by a user. For more information, see Controlling User Access to Pipelines in the AWS Data Pipeline Developer Guide .\n\n\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{}


Response Structure

(dict) --
Contains the output of AddTags.





Exceptions

DataPipeline.Client.exceptions.InternalServiceError
DataPipeline.Client.exceptions.InvalidRequestException
DataPipeline.Client.exceptions.PipelineNotFoundException
DataPipeline.Client.exceptions.PipelineDeletedException


    :return: {}
    
    
    :returns: 
    DataPipeline.Client.exceptions.InternalServiceError
    DataPipeline.Client.exceptions.InvalidRequestException
    DataPipeline.Client.exceptions.PipelineNotFoundException
    DataPipeline.Client.exceptions.PipelineDeletedException
    
    """
    pass

def can_paginate(operation_name=None):
    """
    Check if an operation can be paginated.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name\nas the method name on the client. For example, if the\nmethod name is create_foo, and you\'d normally invoke the\noperation as client.create_foo(**kwargs), if the\ncreate_foo operation can be paginated, you can use the\ncall client.get_paginator('create_foo').

    """
    pass

def create_pipeline(name=None, uniqueId=None, description=None, tags=None):
    """
    Creates a new, empty pipeline. Use  PutPipelineDefinition to populate the pipeline.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.create_pipeline(
        name='string',
        uniqueId='string',
        description='string',
        tags=[
            {
                'key': 'string',
                'value': 'string'
            },
        ]
    )
    
    
    :type name: string
    :param name: [REQUIRED]\nThe name for the pipeline. You can use the same name for multiple pipelines associated with your AWS account, because AWS Data Pipeline assigns each pipeline a unique pipeline identifier.\n

    :type uniqueId: string
    :param uniqueId: [REQUIRED]\nA unique identifier. This identifier is not the same as the pipeline identifier assigned by AWS Data Pipeline. You are responsible for defining the format and ensuring the uniqueness of this identifier. You use this parameter to ensure idempotency during repeated calls to CreatePipeline . For example, if the first call to CreatePipeline does not succeed, you can pass in the same unique identifier and pipeline name combination on a subsequent call to CreatePipeline . CreatePipeline ensures that if a pipeline already exists with the same name and unique identifier, a new pipeline is not created. Instead, you\'ll receive the pipeline identifier from the previous attempt. The uniqueness of the name and unique identifier combination is scoped to the AWS account or IAM user credentials.\n

    :type description: string
    :param description: The description for the pipeline.

    :type tags: list
    :param tags: A list of tags to associate with the pipeline at creation. Tags let you control access to pipelines. For more information, see Controlling User Access to Pipelines in the AWS Data Pipeline Developer Guide .\n\n(dict) --Tags are key/value pairs defined by a user and associated with a pipeline to control access. AWS Data Pipeline allows you to associate ten tags per pipeline. For more information, see Controlling User Access to Pipelines in the AWS Data Pipeline Developer Guide .\n\nkey (string) -- [REQUIRED]The key name of a tag defined by a user. For more information, see Controlling User Access to Pipelines in the AWS Data Pipeline Developer Guide .\n\nvalue (string) -- [REQUIRED]The optional value portion of a tag defined by a user. For more information, see Controlling User Access to Pipelines in the AWS Data Pipeline Developer Guide .\n\n\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'pipelineId': 'string'
}


Response Structure

(dict) --
Contains the output of CreatePipeline.

pipelineId (string) --
The ID that AWS Data Pipeline assigns the newly created pipeline. For example, df-06372391ZG65EXAMPLE .







Exceptions

DataPipeline.Client.exceptions.InternalServiceError
DataPipeline.Client.exceptions.InvalidRequestException


    :return: {
        'pipelineId': 'string'
    }
    
    
    :returns: 
    DataPipeline.Client.exceptions.InternalServiceError
    DataPipeline.Client.exceptions.InvalidRequestException
    
    """
    pass

def deactivate_pipeline(pipelineId=None, cancelActive=None):
    """
    Deactivates the specified running pipeline. The pipeline is set to the DEACTIVATING state until the deactivation process completes.
    To resume a deactivated pipeline, use  ActivatePipeline . By default, the pipeline resumes from the last completed execution. Optionally, you can specify the date and time to resume the pipeline.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.deactivate_pipeline(
        pipelineId='string',
        cancelActive=True|False
    )
    
    
    :type pipelineId: string
    :param pipelineId: [REQUIRED]\nThe ID of the pipeline.\n

    :type cancelActive: boolean
    :param cancelActive: Indicates whether to cancel any running objects. The default is true, which sets the state of any running objects to CANCELED . If this value is false, the pipeline is deactivated after all running objects finish.

    :rtype: dict

ReturnsResponse Syntax
{}


Response Structure

(dict) --
Contains the output of DeactivatePipeline.





Exceptions

DataPipeline.Client.exceptions.PipelineNotFoundException
DataPipeline.Client.exceptions.PipelineDeletedException
DataPipeline.Client.exceptions.InternalServiceError
DataPipeline.Client.exceptions.InvalidRequestException


    :return: {}
    
    
    :returns: 
    DataPipeline.Client.exceptions.PipelineNotFoundException
    DataPipeline.Client.exceptions.PipelineDeletedException
    DataPipeline.Client.exceptions.InternalServiceError
    DataPipeline.Client.exceptions.InvalidRequestException
    
    """
    pass

def delete_pipeline(pipelineId=None):
    """
    Deletes a pipeline, its pipeline definition, and its run history. AWS Data Pipeline attempts to cancel instances associated with the pipeline that are currently being processed by task runners.
    Deleting a pipeline cannot be undone. You cannot query or restore a deleted pipeline. To temporarily pause a pipeline instead of deleting it, call  SetStatus with the status set to PAUSE on individual components. Components that are paused by  SetStatus can be resumed.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.delete_pipeline(
        pipelineId='string'
    )
    
    
    :type pipelineId: string
    :param pipelineId: [REQUIRED]\nThe ID of the pipeline.\n

    """
    pass

def describe_objects(pipelineId=None, objectIds=None, evaluateExpressions=None, marker=None):
    """
    Gets the object definitions for a set of objects associated with the pipeline. Object definitions are composed of a set of fields that define the properties of the object.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.describe_objects(
        pipelineId='string',
        objectIds=[
            'string',
        ],
        evaluateExpressions=True|False,
        marker='string'
    )
    
    
    :type pipelineId: string
    :param pipelineId: [REQUIRED]\nThe ID of the pipeline that contains the object definitions.\n

    :type objectIds: list
    :param objectIds: [REQUIRED]\nThe IDs of the pipeline objects that contain the definitions to be described. You can pass as many as 25 identifiers in a single call to DescribeObjects .\n\n(string) --\n\n

    :type evaluateExpressions: boolean
    :param evaluateExpressions: Indicates whether any expressions in the object should be evaluated when the object descriptions are returned.

    :type marker: string
    :param marker: The starting point for the results to be returned. For the first call, this value should be empty. As long as there are more results, continue to call DescribeObjects with the marker value from the previous call to retrieve the next set of results.

    :rtype: dict

ReturnsResponse Syntax
{
    'pipelineObjects': [
        {
            'id': 'string',
            'name': 'string',
            'fields': [
                {
                    'key': 'string',
                    'stringValue': 'string',
                    'refValue': 'string'
                },
            ]
        },
    ],
    'marker': 'string',
    'hasMoreResults': True|False
}


Response Structure

(dict) --
Contains the output of DescribeObjects.

pipelineObjects (list) --
An array of object definitions.

(dict) --
Contains information about a pipeline object. This can be a logical, physical, or physical attempt pipeline object. The complete set of components of a pipeline defines the pipeline.

id (string) --
The ID of the object.

name (string) --
The name of the object.

fields (list) --
Key-value pairs that define the properties of the object.

(dict) --
A key-value pair that describes a property of a pipeline object. The value is specified as either a string value (StringValue ) or a reference to another object (RefValue ) but not as both.

key (string) --
The field identifier.

stringValue (string) --
The field value, expressed as a String.

refValue (string) --
The field value, expressed as the identifier of another object.









marker (string) --
The starting point for the next page of results. To view the next page of results, call DescribeObjects again with this marker value. If the value is null, there are no more results.

hasMoreResults (boolean) --
Indicates whether there are more results to return.







Exceptions

DataPipeline.Client.exceptions.InternalServiceError
DataPipeline.Client.exceptions.InvalidRequestException
DataPipeline.Client.exceptions.PipelineNotFoundException
DataPipeline.Client.exceptions.PipelineDeletedException


    :return: {
        'pipelineObjects': [
            {
                'id': 'string',
                'name': 'string',
                'fields': [
                    {
                        'key': 'string',
                        'stringValue': 'string',
                        'refValue': 'string'
                    },
                ]
            },
        ],
        'marker': 'string',
        'hasMoreResults': True|False
    }
    
    
    :returns: 
    DataPipeline.Client.exceptions.InternalServiceError
    DataPipeline.Client.exceptions.InvalidRequestException
    DataPipeline.Client.exceptions.PipelineNotFoundException
    DataPipeline.Client.exceptions.PipelineDeletedException
    
    """
    pass

def describe_pipelines(pipelineIds=None):
    """
    Retrieves metadata about one or more pipelines. The information retrieved includes the name of the pipeline, the pipeline identifier, its current state, and the user account that owns the pipeline. Using account credentials, you can retrieve metadata about pipelines that you or your IAM users have created. If you are using an IAM user account, you can retrieve metadata about only those pipelines for which you have read permissions.
    To retrieve the full pipeline definition instead of metadata about the pipeline, call  GetPipelineDefinition .
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.describe_pipelines(
        pipelineIds=[
            'string',
        ]
    )
    
    
    :type pipelineIds: list
    :param pipelineIds: [REQUIRED]\nThe IDs of the pipelines to describe. You can pass as many as 25 identifiers in a single call. To obtain pipeline IDs, call ListPipelines .\n\n(string) --\n\n

    :rtype: dict
ReturnsResponse Syntax{
    'pipelineDescriptionList': [
        {
            'pipelineId': 'string',
            'name': 'string',
            'fields': [
                {
                    'key': 'string',
                    'stringValue': 'string',
                    'refValue': 'string'
                },
            ],
            'description': 'string',
            'tags': [
                {
                    'key': 'string',
                    'value': 'string'
                },
            ]
        },
    ]
}


Response Structure

(dict) --Contains the output of DescribePipelines.

pipelineDescriptionList (list) --An array of descriptions for the specified pipelines.

(dict) --Contains pipeline metadata.

pipelineId (string) --The pipeline identifier that was assigned by AWS Data Pipeline. This is a string of the form df-297EG78HU43EEXAMPLE .

name (string) --The name of the pipeline.

fields (list) --A list of read-only fields that contain metadata about the pipeline: @userId, @accountId, and @pipelineState.

(dict) --A key-value pair that describes a property of a pipeline object. The value is specified as either a string value (StringValue ) or a reference to another object (RefValue ) but not as both.

key (string) --The field identifier.

stringValue (string) --The field value, expressed as a String.

refValue (string) --The field value, expressed as the identifier of another object.





description (string) --Description of the pipeline.

tags (list) --A list of tags to associated with a pipeline. Tags let you control access to pipelines. For more information, see Controlling User Access to Pipelines in the AWS Data Pipeline Developer Guide .

(dict) --Tags are key/value pairs defined by a user and associated with a pipeline to control access. AWS Data Pipeline allows you to associate ten tags per pipeline. For more information, see Controlling User Access to Pipelines in the AWS Data Pipeline Developer Guide .

key (string) --The key name of a tag defined by a user. For more information, see Controlling User Access to Pipelines in the AWS Data Pipeline Developer Guide .

value (string) --The optional value portion of a tag defined by a user. For more information, see Controlling User Access to Pipelines in the AWS Data Pipeline Developer Guide .














Exceptions

DataPipeline.Client.exceptions.PipelineNotFoundException
DataPipeline.Client.exceptions.PipelineDeletedException
DataPipeline.Client.exceptions.InternalServiceError
DataPipeline.Client.exceptions.InvalidRequestException


    :return: {
        'pipelineDescriptionList': [
            {
                'pipelineId': 'string',
                'name': 'string',
                'fields': [
                    {
                        'key': 'string',
                        'stringValue': 'string',
                        'refValue': 'string'
                    },
                ],
                'description': 'string',
                'tags': [
                    {
                        'key': 'string',
                        'value': 'string'
                    },
                ]
            },
        ]
    }
    
    
    :returns: 
    DataPipeline.Client.exceptions.PipelineNotFoundException
    DataPipeline.Client.exceptions.PipelineDeletedException
    DataPipeline.Client.exceptions.InternalServiceError
    DataPipeline.Client.exceptions.InvalidRequestException
    
    """
    pass

def evaluate_expression(pipelineId=None, objectId=None, expression=None):
    """
    Task runners call EvaluateExpression to evaluate a string in the context of the specified object. For example, a task runner can evaluate SQL queries stored in Amazon S3.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.evaluate_expression(
        pipelineId='string',
        objectId='string',
        expression='string'
    )
    
    
    :type pipelineId: string
    :param pipelineId: [REQUIRED]\nThe ID of the pipeline.\n

    :type objectId: string
    :param objectId: [REQUIRED]\nThe ID of the object.\n

    :type expression: string
    :param expression: [REQUIRED]\nThe expression to evaluate.\n

    :rtype: dict

ReturnsResponse Syntax
{
    'evaluatedExpression': 'string'
}


Response Structure

(dict) --
Contains the output of EvaluateExpression.

evaluatedExpression (string) --
The evaluated expression.







Exceptions

DataPipeline.Client.exceptions.InternalServiceError
DataPipeline.Client.exceptions.TaskNotFoundException
DataPipeline.Client.exceptions.InvalidRequestException
DataPipeline.Client.exceptions.PipelineNotFoundException
DataPipeline.Client.exceptions.PipelineDeletedException


    :return: {
        'evaluatedExpression': 'string'
    }
    
    
    :returns: 
    DataPipeline.Client.exceptions.InternalServiceError
    DataPipeline.Client.exceptions.TaskNotFoundException
    DataPipeline.Client.exceptions.InvalidRequestException
    DataPipeline.Client.exceptions.PipelineNotFoundException
    DataPipeline.Client.exceptions.PipelineDeletedException
    
    """
    pass

def generate_presigned_url(ClientMethod=None, Params=None, ExpiresIn=None, HttpMethod=None):
    """
    Generate a presigned url given a client, its method, and arguments
    
    :type ClientMethod: string
    :param ClientMethod: The client method to presign for

    :type Params: dict
    :param Params: The parameters normally passed to\nClientMethod.

    :type ExpiresIn: int
    :param ExpiresIn: The number of seconds the presigned url is valid\nfor. By default it expires in an hour (3600 seconds)

    :type HttpMethod: string
    :param HttpMethod: The http method to use on the generated url. By\ndefault, the http method is whatever is used in the method\'s model.

    """
    pass

def get_paginator(operation_name=None):
    """
    Create a paginator for an operation.
    
    :type operation_name: string
    :param operation_name: The operation name. This is the same name\nas the method name on the client. For example, if the\nmethod name is create_foo, and you\'d normally invoke the\noperation as client.create_foo(**kwargs), if the\ncreate_foo operation can be paginated, you can use the\ncall client.get_paginator('create_foo').

    :rtype: L{botocore.paginate.Paginator}
ReturnsA paginator object.


    """
    pass

def get_pipeline_definition(pipelineId=None, version=None):
    """
    Gets the definition of the specified pipeline. You can call GetPipelineDefinition to retrieve the pipeline definition that you provided using  PutPipelineDefinition .
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.get_pipeline_definition(
        pipelineId='string',
        version='string'
    )
    
    
    :type pipelineId: string
    :param pipelineId: [REQUIRED]\nThe ID of the pipeline.\n

    :type version: string
    :param version: The version of the pipeline definition to retrieve. Set this parameter to latest (default) to use the last definition saved to the pipeline or active to use the last definition that was activated.

    :rtype: dict

ReturnsResponse Syntax
{
    'pipelineObjects': [
        {
            'id': 'string',
            'name': 'string',
            'fields': [
                {
                    'key': 'string',
                    'stringValue': 'string',
                    'refValue': 'string'
                },
            ]
        },
    ],
    'parameterObjects': [
        {
            'id': 'string',
            'attributes': [
                {
                    'key': 'string',
                    'stringValue': 'string'
                },
            ]
        },
    ],
    'parameterValues': [
        {
            'id': 'string',
            'stringValue': 'string'
        },
    ]
}


Response Structure

(dict) --
Contains the output of GetPipelineDefinition.

pipelineObjects (list) --
The objects defined in the pipeline.

(dict) --
Contains information about a pipeline object. This can be a logical, physical, or physical attempt pipeline object. The complete set of components of a pipeline defines the pipeline.

id (string) --
The ID of the object.

name (string) --
The name of the object.

fields (list) --
Key-value pairs that define the properties of the object.

(dict) --
A key-value pair that describes a property of a pipeline object. The value is specified as either a string value (StringValue ) or a reference to another object (RefValue ) but not as both.

key (string) --
The field identifier.

stringValue (string) --
The field value, expressed as a String.

refValue (string) --
The field value, expressed as the identifier of another object.









parameterObjects (list) --
The parameter objects used in the pipeline definition.

(dict) --
Contains information about a parameter object.

id (string) --
The ID of the parameter object.

attributes (list) --
The attributes of the parameter object.

(dict) --
The attributes allowed or specified with a parameter object.

key (string) --
The field identifier.

stringValue (string) --
The field value, expressed as a String.









parameterValues (list) --
The parameter values used in the pipeline definition.

(dict) --
A value or list of parameter values.

id (string) --
The ID of the parameter value.

stringValue (string) --
The field value, expressed as a String.











Exceptions

DataPipeline.Client.exceptions.InternalServiceError
DataPipeline.Client.exceptions.InvalidRequestException
DataPipeline.Client.exceptions.PipelineNotFoundException
DataPipeline.Client.exceptions.PipelineDeletedException


    :return: {
        'pipelineObjects': [
            {
                'id': 'string',
                'name': 'string',
                'fields': [
                    {
                        'key': 'string',
                        'stringValue': 'string',
                        'refValue': 'string'
                    },
                ]
            },
        ],
        'parameterObjects': [
            {
                'id': 'string',
                'attributes': [
                    {
                        'key': 'string',
                        'stringValue': 'string'
                    },
                ]
            },
        ],
        'parameterValues': [
            {
                'id': 'string',
                'stringValue': 'string'
            },
        ]
    }
    
    
    :returns: 
    DataPipeline.Client.exceptions.InternalServiceError
    DataPipeline.Client.exceptions.InvalidRequestException
    DataPipeline.Client.exceptions.PipelineNotFoundException
    DataPipeline.Client.exceptions.PipelineDeletedException
    
    """
    pass

def get_waiter(waiter_name=None):
    """
    Returns an object that can wait for some condition.
    
    :type waiter_name: str
    :param waiter_name: The name of the waiter to get. See the waiters\nsection of the service docs for a list of available waiters.

    :rtype: botocore.waiter.Waiter


    """
    pass

def list_pipelines(marker=None):
    """
    Lists the pipeline identifiers for all active pipelines that you have permission to access.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.list_pipelines(
        marker='string'
    )
    
    
    :type marker: string
    :param marker: The starting point for the results to be returned. For the first call, this value should be empty. As long as there are more results, continue to call ListPipelines with the marker value from the previous call to retrieve the next set of results.

    :rtype: dict
ReturnsResponse Syntax{
    'pipelineIdList': [
        {
            'id': 'string',
            'name': 'string'
        },
    ],
    'marker': 'string',
    'hasMoreResults': True|False
}


Response Structure

(dict) --Contains the output of ListPipelines.

pipelineIdList (list) --The pipeline identifiers. If you require additional information about the pipelines, you can use these identifiers to call  DescribePipelines and  GetPipelineDefinition .

(dict) --Contains the name and identifier of a pipeline.

id (string) --The ID of the pipeline that was assigned by AWS Data Pipeline. This is a string of the form df-297EG78HU43EEXAMPLE .

name (string) --The name of the pipeline.





marker (string) --The starting point for the next page of results. To view the next page of results, call ListPipelinesOutput again with this marker value. If the value is null, there are no more results.

hasMoreResults (boolean) --Indicates whether there are more results that can be obtained by a subsequent call.






Exceptions

DataPipeline.Client.exceptions.InternalServiceError
DataPipeline.Client.exceptions.InvalidRequestException


    :return: {
        'pipelineIdList': [
            {
                'id': 'string',
                'name': 'string'
            },
        ],
        'marker': 'string',
        'hasMoreResults': True|False
    }
    
    
    """
    pass

def poll_for_task(workerGroup=None, hostname=None, instanceIdentity=None):
    """
    Task runners call PollForTask to receive a task to perform from AWS Data Pipeline. The task runner specifies which tasks it can perform by setting a value for the workerGroup parameter. The task returned can come from any of the pipelines that match the workerGroup value passed in by the task runner and that was launched using the IAM user credentials specified by the task runner.
    If tasks are ready in the work queue, PollForTask returns a response immediately. If no tasks are available in the queue, PollForTask uses long-polling and holds on to a poll connection for up to a 90 seconds, during which time the first newly scheduled task is handed to the task runner. To accomodate this, set the socket timeout in your task runner to 90 seconds. The task runner should not call PollForTask again on the same workerGroup until it receives a response, and this can take up to 90 seconds.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.poll_for_task(
        workerGroup='string',
        hostname='string',
        instanceIdentity={
            'document': 'string',
            'signature': 'string'
        }
    )
    
    
    :type workerGroup: string
    :param workerGroup: [REQUIRED]\nThe type of task the task runner is configured to accept and process. The worker group is set as a field on objects in the pipeline when they are created. You can only specify a single value for workerGroup in the call to PollForTask . There are no wildcard values permitted in workerGroup ; the string must be an exact, case-sensitive, match.\n

    :type hostname: string
    :param hostname: The public DNS name of the calling task runner.

    :type instanceIdentity: dict
    :param instanceIdentity: Identity information for the EC2 instance that is hosting the task runner. You can get this value from the instance using http://169.254.169.254/latest/meta-data/instance-id . For more information, see Instance Metadata in the Amazon Elastic Compute Cloud User Guide. Passing in this value proves that your task runner is running on an EC2 instance, and ensures the proper AWS Data Pipeline service charges are applied to your pipeline.\n\ndocument (string) --A description of an EC2 instance that is generated when the instance is launched and exposed to the instance via the instance metadata service in the form of a JSON representation of an object.\n\nsignature (string) --A signature which can be used to verify the accuracy and authenticity of the information provided in the instance identity document.\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'taskObject': {
        'taskId': 'string',
        'pipelineId': 'string',
        'attemptId': 'string',
        'objects': {
            'string': {
                'id': 'string',
                'name': 'string',
                'fields': [
                    {
                        'key': 'string',
                        'stringValue': 'string',
                        'refValue': 'string'
                    },
                ]
            }
        }
    }
}


Response Structure

(dict) --
Contains the output of PollForTask.

taskObject (dict) --
The information needed to complete the task that is being assigned to the task runner. One of the fields returned in this object is taskId , which contains an identifier for the task being assigned. The calling task runner uses taskId in subsequent calls to  ReportTaskProgress and  SetTaskStatus .

taskId (string) --
An internal identifier for the task. This ID is passed to the  SetTaskStatus and  ReportTaskProgress actions.

pipelineId (string) --
The ID of the pipeline that provided the task.

attemptId (string) --
The ID of the pipeline task attempt object. AWS Data Pipeline uses this value to track how many times a task is attempted.

objects (dict) --
Connection information for the location where the task runner will publish the output of the task.

(string) --

(dict) --
Contains information about a pipeline object. This can be a logical, physical, or physical attempt pipeline object. The complete set of components of a pipeline defines the pipeline.

id (string) --
The ID of the object.

name (string) --
The name of the object.

fields (list) --
Key-value pairs that define the properties of the object.

(dict) --
A key-value pair that describes a property of a pipeline object. The value is specified as either a string value (StringValue ) or a reference to another object (RefValue ) but not as both.

key (string) --
The field identifier.

stringValue (string) --
The field value, expressed as a String.

refValue (string) --
The field value, expressed as the identifier of another object.



















Exceptions

DataPipeline.Client.exceptions.InternalServiceError
DataPipeline.Client.exceptions.InvalidRequestException
DataPipeline.Client.exceptions.TaskNotFoundException


    :return: {
        'taskObject': {
            'taskId': 'string',
            'pipelineId': 'string',
            'attemptId': 'string',
            'objects': {
                'string': {
                    'id': 'string',
                    'name': 'string',
                    'fields': [
                        {
                            'key': 'string',
                            'stringValue': 'string',
                            'refValue': 'string'
                        },
                    ]
                }
            }
        }
    }
    
    
    :returns: 
    DataPipeline.Client.exceptions.InternalServiceError
    DataPipeline.Client.exceptions.InvalidRequestException
    DataPipeline.Client.exceptions.TaskNotFoundException
    
    """
    pass

def put_pipeline_definition(pipelineId=None, pipelineObjects=None, parameterObjects=None, parameterValues=None):
    """
    Adds tasks, schedules, and preconditions to the specified pipeline. You can use PutPipelineDefinition to populate a new pipeline.
    Pipeline object definitions are passed to the PutPipelineDefinition action and returned by the  GetPipelineDefinition action.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.put_pipeline_definition(
        pipelineId='string',
        pipelineObjects=[
            {
                'id': 'string',
                'name': 'string',
                'fields': [
                    {
                        'key': 'string',
                        'stringValue': 'string',
                        'refValue': 'string'
                    },
                ]
            },
        ],
        parameterObjects=[
            {
                'id': 'string',
                'attributes': [
                    {
                        'key': 'string',
                        'stringValue': 'string'
                    },
                ]
            },
        ],
        parameterValues=[
            {
                'id': 'string',
                'stringValue': 'string'
            },
        ]
    )
    
    
    :type pipelineId: string
    :param pipelineId: [REQUIRED]\nThe ID of the pipeline.\n

    :type pipelineObjects: list
    :param pipelineObjects: [REQUIRED]\nThe objects that define the pipeline. These objects overwrite the existing pipeline definition.\n\n(dict) --Contains information about a pipeline object. This can be a logical, physical, or physical attempt pipeline object. The complete set of components of a pipeline defines the pipeline.\n\nid (string) -- [REQUIRED]The ID of the object.\n\nname (string) -- [REQUIRED]The name of the object.\n\nfields (list) -- [REQUIRED]Key-value pairs that define the properties of the object.\n\n(dict) --A key-value pair that describes a property of a pipeline object. The value is specified as either a string value (StringValue ) or a reference to another object (RefValue ) but not as both.\n\nkey (string) -- [REQUIRED]The field identifier.\n\nstringValue (string) --The field value, expressed as a String.\n\nrefValue (string) --The field value, expressed as the identifier of another object.\n\n\n\n\n\n\n\n\n

    :type parameterObjects: list
    :param parameterObjects: The parameter objects used with the pipeline.\n\n(dict) --Contains information about a parameter object.\n\nid (string) -- [REQUIRED]The ID of the parameter object.\n\nattributes (list) -- [REQUIRED]The attributes of the parameter object.\n\n(dict) --The attributes allowed or specified with a parameter object.\n\nkey (string) -- [REQUIRED]The field identifier.\n\nstringValue (string) -- [REQUIRED]The field value, expressed as a String.\n\n\n\n\n\n\n\n\n

    :type parameterValues: list
    :param parameterValues: The parameter values used with the pipeline.\n\n(dict) --A value or list of parameter values.\n\nid (string) -- [REQUIRED]The ID of the parameter value.\n\nstringValue (string) -- [REQUIRED]The field value, expressed as a String.\n\n\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'validationErrors': [
        {
            'id': 'string',
            'errors': [
                'string',
            ]
        },
    ],
    'validationWarnings': [
        {
            'id': 'string',
            'warnings': [
                'string',
            ]
        },
    ],
    'errored': True|False
}


Response Structure

(dict) --
Contains the output of PutPipelineDefinition.

validationErrors (list) --
The validation errors that are associated with the objects defined in pipelineObjects .

(dict) --
Defines a validation error. Validation errors prevent pipeline activation. The set of validation errors that can be returned are defined by AWS Data Pipeline.

id (string) --
The identifier of the object that contains the validation error.

errors (list) --
A description of the validation error.

(string) --






validationWarnings (list) --
The validation warnings that are associated with the objects defined in pipelineObjects .

(dict) --
Defines a validation warning. Validation warnings do not prevent pipeline activation. The set of validation warnings that can be returned are defined by AWS Data Pipeline.

id (string) --
The identifier of the object that contains the validation warning.

warnings (list) --
A description of the validation warning.

(string) --






errored (boolean) --
Indicates whether there were validation errors, and the pipeline definition is stored but cannot be activated until you correct the pipeline and call PutPipelineDefinition to commit the corrected pipeline.







Exceptions

DataPipeline.Client.exceptions.InternalServiceError
DataPipeline.Client.exceptions.InvalidRequestException
DataPipeline.Client.exceptions.PipelineNotFoundException
DataPipeline.Client.exceptions.PipelineDeletedException


    :return: {
        'validationErrors': [
            {
                'id': 'string',
                'errors': [
                    'string',
                ]
            },
        ],
        'validationWarnings': [
            {
                'id': 'string',
                'warnings': [
                    'string',
                ]
            },
        ],
        'errored': True|False
    }
    
    
    :returns: 
    pipelineId (string) -- [REQUIRED]
    The ID of the pipeline.
    
    pipelineObjects (list) -- [REQUIRED]
    The objects that define the pipeline. These objects overwrite the existing pipeline definition.
    
    (dict) --Contains information about a pipeline object. This can be a logical, physical, or physical attempt pipeline object. The complete set of components of a pipeline defines the pipeline.
    
    id (string) -- [REQUIRED]The ID of the object.
    
    name (string) -- [REQUIRED]The name of the object.
    
    fields (list) -- [REQUIRED]Key-value pairs that define the properties of the object.
    
    (dict) --A key-value pair that describes a property of a pipeline object. The value is specified as either a string value (StringValue ) or a reference to another object (RefValue ) but not as both.
    
    key (string) -- [REQUIRED]The field identifier.
    
    stringValue (string) --The field value, expressed as a String.
    
    refValue (string) --The field value, expressed as the identifier of another object.
    
    
    
    
    
    
    
    
    
    parameterObjects (list) -- The parameter objects used with the pipeline.
    
    (dict) --Contains information about a parameter object.
    
    id (string) -- [REQUIRED]The ID of the parameter object.
    
    attributes (list) -- [REQUIRED]The attributes of the parameter object.
    
    (dict) --The attributes allowed or specified with a parameter object.
    
    key (string) -- [REQUIRED]The field identifier.
    
    stringValue (string) -- [REQUIRED]The field value, expressed as a String.
    
    
    
    
    
    
    
    
    
    parameterValues (list) -- The parameter values used with the pipeline.
    
    (dict) --A value or list of parameter values.
    
    id (string) -- [REQUIRED]The ID of the parameter value.
    
    stringValue (string) -- [REQUIRED]The field value, expressed as a String.
    
    
    
    
    
    
    """
    pass

def query_objects(pipelineId=None, query=None, sphere=None, marker=None, limit=None):
    """
    Queries the specified pipeline for the names of objects that match the specified set of conditions.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.query_objects(
        pipelineId='string',
        query={
            'selectors': [
                {
                    'fieldName': 'string',
                    'operator': {
                        'type': 'EQ'|'REF_EQ'|'LE'|'GE'|'BETWEEN',
                        'values': [
                            'string',
                        ]
                    }
                },
            ]
        },
        sphere='string',
        marker='string',
        limit=123
    )
    
    
    :type pipelineId: string
    :param pipelineId: [REQUIRED]\nThe ID of the pipeline.\n

    :type query: dict
    :param query: The query that defines the objects to be returned. The Query object can contain a maximum of ten selectors. The conditions in the query are limited to top-level String fields in the object. These filters can be applied to components, instances, and attempts.\n\nselectors (list) --List of selectors that define the query. An object must satisfy all of the selectors to match the query.\n\n(dict) --A comparision that is used to determine whether a query should return this object.\n\nfieldName (string) --The name of the field that the operator will be applied to. The field name is the 'key' portion of the field definition in the pipeline definition syntax that is used by the AWS Data Pipeline API. If the field is not set on the object, the condition fails.\n\noperator (dict) --Contains a logical operation for comparing the value of a field with a specified value.\n\ntype (string) --The logical operation to be performed: equal (EQ ), equal reference (REF_EQ ), less than or equal (LE ), greater than or equal (GE ), or between (BETWEEN ). Equal reference (REF_EQ ) can be used only with reference fields. The other comparison types can be used only with String fields. The comparison types you can use apply only to certain object fields, as detailed below.\nThe comparison operators EQ and REF_EQ act on the following fields:\n\nname\n@sphere\nparent\n@componentParent\n@instanceParent\n@status\n@scheduledStartTime\n@scheduledEndTime\n@actualStartTime\n@actualEndTime\n\nThe comparison operators GE , LE , and BETWEEN act on the following fields:\n\n@scheduledStartTime\n@scheduledEndTime\n@actualStartTime\n@actualEndTime\n\nNote that fields beginning with the at sign (@) are read-only and set by the web service. When you name fields, you should choose names containing only alpha-numeric values, as symbols may be reserved by AWS Data Pipeline. User-defined fields that you add to a pipeline should prefix their name with the string 'my'.\n\nvalues (list) --The value that the actual field value will be compared with.\n\n(string) --\n\n\n\n\n\n\n\n\n\n

    :type sphere: string
    :param sphere: [REQUIRED]\nIndicates whether the query applies to components or instances. The possible values are: COMPONENT , INSTANCE , and ATTEMPT .\n

    :type marker: string
    :param marker: The starting point for the results to be returned. For the first call, this value should be empty. As long as there are more results, continue to call QueryObjects with the marker value from the previous call to retrieve the next set of results.

    :type limit: integer
    :param limit: The maximum number of object names that QueryObjects will return in a single call. The default value is 100.

    :rtype: dict

ReturnsResponse Syntax
{
    'ids': [
        'string',
    ],
    'marker': 'string',
    'hasMoreResults': True|False
}


Response Structure

(dict) --
Contains the output of QueryObjects.

ids (list) --
The identifiers that match the query selectors.

(string) --


marker (string) --
The starting point for the next page of results. To view the next page of results, call QueryObjects again with this marker value. If the value is null, there are no more results.

hasMoreResults (boolean) --
Indicates whether there are more results that can be obtained by a subsequent call.







Exceptions

DataPipeline.Client.exceptions.PipelineNotFoundException
DataPipeline.Client.exceptions.PipelineDeletedException
DataPipeline.Client.exceptions.InternalServiceError
DataPipeline.Client.exceptions.InvalidRequestException


    :return: {
        'ids': [
            'string',
        ],
        'marker': 'string',
        'hasMoreResults': True|False
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

def remove_tags(pipelineId=None, tagKeys=None):
    """
    Removes existing tags from the specified pipeline.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.remove_tags(
        pipelineId='string',
        tagKeys=[
            'string',
        ]
    )
    
    
    :type pipelineId: string
    :param pipelineId: [REQUIRED]\nThe ID of the pipeline.\n

    :type tagKeys: list
    :param tagKeys: [REQUIRED]\nThe keys of the tags to remove.\n\n(string) --\n\n

    :rtype: dict

ReturnsResponse Syntax
{}


Response Structure

(dict) --
Contains the output of RemoveTags.





Exceptions

DataPipeline.Client.exceptions.InternalServiceError
DataPipeline.Client.exceptions.InvalidRequestException
DataPipeline.Client.exceptions.PipelineNotFoundException
DataPipeline.Client.exceptions.PipelineDeletedException


    :return: {}
    
    
    :returns: 
    DataPipeline.Client.exceptions.InternalServiceError
    DataPipeline.Client.exceptions.InvalidRequestException
    DataPipeline.Client.exceptions.PipelineNotFoundException
    DataPipeline.Client.exceptions.PipelineDeletedException
    
    """
    pass

def report_task_progress(taskId=None, fields=None):
    """
    Task runners call ReportTaskProgress when assigned a task to acknowledge that it has the task. If the web service does not receive this acknowledgement within 2 minutes, it assigns the task in a subsequent  PollForTask call. After this initial acknowledgement, the task runner only needs to report progress every 15 minutes to maintain its ownership of the task. You can change this reporting time from 15 minutes by specifying a reportProgressTimeout field in your pipeline.
    If a task runner does not report its status after 5 minutes, AWS Data Pipeline assumes that the task runner is unable to process the task and reassigns the task in a subsequent response to  PollForTask . Task runners should call ReportTaskProgress every 60 seconds.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.report_task_progress(
        taskId='string',
        fields=[
            {
                'key': 'string',
                'stringValue': 'string',
                'refValue': 'string'
            },
        ]
    )
    
    
    :type taskId: string
    :param taskId: [REQUIRED]\nThe ID of the task assigned to the task runner. This value is provided in the response for PollForTask .\n

    :type fields: list
    :param fields: Key-value pairs that define the properties of the ReportTaskProgressInput object.\n\n(dict) --A key-value pair that describes a property of a pipeline object. The value is specified as either a string value (StringValue ) or a reference to another object (RefValue ) but not as both.\n\nkey (string) -- [REQUIRED]The field identifier.\n\nstringValue (string) --The field value, expressed as a String.\n\nrefValue (string) --The field value, expressed as the identifier of another object.\n\n\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'canceled': True|False
}


Response Structure

(dict) --
Contains the output of ReportTaskProgress.

canceled (boolean) --
If true, the calling task runner should cancel processing of the task. The task runner does not need to call  SetTaskStatus for canceled tasks.







Exceptions

DataPipeline.Client.exceptions.InternalServiceError
DataPipeline.Client.exceptions.InvalidRequestException
DataPipeline.Client.exceptions.TaskNotFoundException
DataPipeline.Client.exceptions.PipelineNotFoundException
DataPipeline.Client.exceptions.PipelineDeletedException


    :return: {
        'canceled': True|False
    }
    
    
    :returns: 
    DataPipeline.Client.exceptions.InternalServiceError
    DataPipeline.Client.exceptions.InvalidRequestException
    DataPipeline.Client.exceptions.TaskNotFoundException
    DataPipeline.Client.exceptions.PipelineNotFoundException
    DataPipeline.Client.exceptions.PipelineDeletedException
    
    """
    pass

def report_task_runner_heartbeat(taskrunnerId=None, workerGroup=None, hostname=None):
    """
    Task runners call ReportTaskRunnerHeartbeat every 15 minutes to indicate that they are operational. If the AWS Data Pipeline Task Runner is launched on a resource managed by AWS Data Pipeline, the web service can use this call to detect when the task runner application has failed and restart a new instance.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.report_task_runner_heartbeat(
        taskrunnerId='string',
        workerGroup='string',
        hostname='string'
    )
    
    
    :type taskrunnerId: string
    :param taskrunnerId: [REQUIRED]\nThe ID of the task runner. This value should be unique across your AWS account. In the case of AWS Data Pipeline Task Runner launched on a resource managed by AWS Data Pipeline, the web service provides a unique identifier when it launches the application. If you have written a custom task runner, you should assign a unique identifier for the task runner.\n

    :type workerGroup: string
    :param workerGroup: The type of task the task runner is configured to accept and process. The worker group is set as a field on objects in the pipeline when they are created. You can only specify a single value for workerGroup . There are no wildcard values permitted in workerGroup ; the string must be an exact, case-sensitive, match.

    :type hostname: string
    :param hostname: The public DNS name of the task runner.

    :rtype: dict

ReturnsResponse Syntax
{
    'terminate': True|False
}


Response Structure

(dict) --
Contains the output of ReportTaskRunnerHeartbeat.

terminate (boolean) --
Indicates whether the calling task runner should terminate.







Exceptions

DataPipeline.Client.exceptions.InternalServiceError
DataPipeline.Client.exceptions.InvalidRequestException


    :return: {
        'terminate': True|False
    }
    
    
    :returns: 
    DataPipeline.Client.exceptions.InternalServiceError
    DataPipeline.Client.exceptions.InvalidRequestException
    
    """
    pass

def set_status(pipelineId=None, objectIds=None, status=None):
    """
    Requests that the status of the specified physical or logical pipeline objects be updated in the specified pipeline. This update might not occur immediately, but is eventually consistent. The status that can be set depends on the type of object (for example, DataNode or Activity). You cannot perform this operation on FINISHED pipelines and attempting to do so returns InvalidRequestException .
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.set_status(
        pipelineId='string',
        objectIds=[
            'string',
        ],
        status='string'
    )
    
    
    :type pipelineId: string
    :param pipelineId: [REQUIRED]\nThe ID of the pipeline that contains the objects.\n

    :type objectIds: list
    :param objectIds: [REQUIRED]\nThe IDs of the objects. The corresponding objects can be either physical or components, but not a mix of both types.\n\n(string) --\n\n

    :type status: string
    :param status: [REQUIRED]\nThe status to be set on all the objects specified in objectIds . For components, use PAUSE or RESUME . For instances, use TRY_CANCEL , RERUN , or MARK_FINISHED .\n

    :returns: 
    DataPipeline.Client.exceptions.PipelineNotFoundException
    DataPipeline.Client.exceptions.PipelineDeletedException
    DataPipeline.Client.exceptions.InternalServiceError
    DataPipeline.Client.exceptions.InvalidRequestException
    
    """
    pass

def set_task_status(taskId=None, taskStatus=None, errorId=None, errorMessage=None, errorStackTrace=None):
    """
    Task runners call SetTaskStatus to notify AWS Data Pipeline that a task is completed and provide information about the final status. A task runner makes this call regardless of whether the task was sucessful. A task runner does not need to call SetTaskStatus for tasks that are canceled by the web service during a call to  ReportTaskProgress .
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.set_task_status(
        taskId='string',
        taskStatus='FINISHED'|'FAILED'|'FALSE',
        errorId='string',
        errorMessage='string',
        errorStackTrace='string'
    )
    
    
    :type taskId: string
    :param taskId: [REQUIRED]\nThe ID of the task assigned to the task runner. This value is provided in the response for PollForTask .\n

    :type taskStatus: string
    :param taskStatus: [REQUIRED]\nIf FINISHED , the task successfully completed. If FAILED , the task ended unsuccessfully. Preconditions use false.\n

    :type errorId: string
    :param errorId: If an error occurred during the task, this value specifies the error code. This value is set on the physical attempt object. It is used to display error information to the user. It should not start with string 'Service_' which is reserved by the system.

    :type errorMessage: string
    :param errorMessage: If an error occurred during the task, this value specifies a text description of the error. This value is set on the physical attempt object. It is used to display error information to the user. The web service does not parse this value.

    :type errorStackTrace: string
    :param errorStackTrace: If an error occurred during the task, this value specifies the stack trace associated with the error. This value is set on the physical attempt object. It is used to display error information to the user. The web service does not parse this value.

    :rtype: dict

ReturnsResponse Syntax
{}


Response Structure

(dict) --
Contains the output of SetTaskStatus.





Exceptions

DataPipeline.Client.exceptions.InternalServiceError
DataPipeline.Client.exceptions.TaskNotFoundException
DataPipeline.Client.exceptions.InvalidRequestException
DataPipeline.Client.exceptions.PipelineNotFoundException
DataPipeline.Client.exceptions.PipelineDeletedException


    :return: {}
    
    
    :returns: 
    DataPipeline.Client.exceptions.InternalServiceError
    DataPipeline.Client.exceptions.TaskNotFoundException
    DataPipeline.Client.exceptions.InvalidRequestException
    DataPipeline.Client.exceptions.PipelineNotFoundException
    DataPipeline.Client.exceptions.PipelineDeletedException
    
    """
    pass

def validate_pipeline_definition(pipelineId=None, pipelineObjects=None, parameterObjects=None, parameterValues=None):
    """
    Validates the specified pipeline definition to ensure that it is well formed and can be run without error.
    See also: AWS API Documentation
    
    Exceptions
    
    :example: response = client.validate_pipeline_definition(
        pipelineId='string',
        pipelineObjects=[
            {
                'id': 'string',
                'name': 'string',
                'fields': [
                    {
                        'key': 'string',
                        'stringValue': 'string',
                        'refValue': 'string'
                    },
                ]
            },
        ],
        parameterObjects=[
            {
                'id': 'string',
                'attributes': [
                    {
                        'key': 'string',
                        'stringValue': 'string'
                    },
                ]
            },
        ],
        parameterValues=[
            {
                'id': 'string',
                'stringValue': 'string'
            },
        ]
    )
    
    
    :type pipelineId: string
    :param pipelineId: [REQUIRED]\nThe ID of the pipeline.\n

    :type pipelineObjects: list
    :param pipelineObjects: [REQUIRED]\nThe objects that define the pipeline changes to validate against the pipeline.\n\n(dict) --Contains information about a pipeline object. This can be a logical, physical, or physical attempt pipeline object. The complete set of components of a pipeline defines the pipeline.\n\nid (string) -- [REQUIRED]The ID of the object.\n\nname (string) -- [REQUIRED]The name of the object.\n\nfields (list) -- [REQUIRED]Key-value pairs that define the properties of the object.\n\n(dict) --A key-value pair that describes a property of a pipeline object. The value is specified as either a string value (StringValue ) or a reference to another object (RefValue ) but not as both.\n\nkey (string) -- [REQUIRED]The field identifier.\n\nstringValue (string) --The field value, expressed as a String.\n\nrefValue (string) --The field value, expressed as the identifier of another object.\n\n\n\n\n\n\n\n\n

    :type parameterObjects: list
    :param parameterObjects: The parameter objects used with the pipeline.\n\n(dict) --Contains information about a parameter object.\n\nid (string) -- [REQUIRED]The ID of the parameter object.\n\nattributes (list) -- [REQUIRED]The attributes of the parameter object.\n\n(dict) --The attributes allowed or specified with a parameter object.\n\nkey (string) -- [REQUIRED]The field identifier.\n\nstringValue (string) -- [REQUIRED]The field value, expressed as a String.\n\n\n\n\n\n\n\n\n

    :type parameterValues: list
    :param parameterValues: The parameter values used with the pipeline.\n\n(dict) --A value or list of parameter values.\n\nid (string) -- [REQUIRED]The ID of the parameter value.\n\nstringValue (string) -- [REQUIRED]The field value, expressed as a String.\n\n\n\n\n

    :rtype: dict

ReturnsResponse Syntax
{
    'validationErrors': [
        {
            'id': 'string',
            'errors': [
                'string',
            ]
        },
    ],
    'validationWarnings': [
        {
            'id': 'string',
            'warnings': [
                'string',
            ]
        },
    ],
    'errored': True|False
}


Response Structure

(dict) --
Contains the output of ValidatePipelineDefinition.

validationErrors (list) --
Any validation errors that were found.

(dict) --
Defines a validation error. Validation errors prevent pipeline activation. The set of validation errors that can be returned are defined by AWS Data Pipeline.

id (string) --
The identifier of the object that contains the validation error.

errors (list) --
A description of the validation error.

(string) --






validationWarnings (list) --
Any validation warnings that were found.

(dict) --
Defines a validation warning. Validation warnings do not prevent pipeline activation. The set of validation warnings that can be returned are defined by AWS Data Pipeline.

id (string) --
The identifier of the object that contains the validation warning.

warnings (list) --
A description of the validation warning.

(string) --






errored (boolean) --
Indicates whether there were validation errors.







Exceptions

DataPipeline.Client.exceptions.InternalServiceError
DataPipeline.Client.exceptions.InvalidRequestException
DataPipeline.Client.exceptions.PipelineNotFoundException
DataPipeline.Client.exceptions.PipelineDeletedException


    :return: {
        'validationErrors': [
            {
                'id': 'string',
                'errors': [
                    'string',
                ]
            },
        ],
        'validationWarnings': [
            {
                'id': 'string',
                'warnings': [
                    'string',
                ]
            },
        ],
        'errored': True|False
    }
    
    
    :returns: 
    (string) --
    
    """
    pass

